Ports
=====

.. py:currentmodule:: alsa_midi

.. autoclass:: Port
   :members:

.. autoclass:: PortInfo
   :members:

.. autoclass:: PortCaps
   :members:
   :undoc-members:

.. autodata:: READ_PORT
   :annotation: = PortCaps.READ | PortCaps.SUBS_READ

.. autodata:: WRITE_PORT
   :annotation: = PortCaps.WRITE | PortCaps.SUBS_WRITE

.. autodata:: RW_PORT
   :annotation: = PortType.MIDI_GENERIC | PortType.SOFTWARE

.. autoclass:: PortType
   :members:
   :undoc-members:

.. autoclass:: SubscriptionQuery
   :members:

.. autoclass:: SubscriptionQueryType
   :members:
   :undoc-members:
